ScanCode.io documentation
=========================

Welcome to the very start of your ScanCode.io journey! In this documentation
you’ll find information on:

- An overview of ScanCode.io and ScanPipe
- Installation instructions
- Tutorials to get you started
- Reference documentation about the ScanPipe concepts, Pipelines, Pipes and more
- How to make technical contributions to the project and the community

.. toctree::
    :maxdepth: 2
    :caption: Getting Started

    introduction
    installation
    user-interface
    faq
    contributing
    changelog

.. toctree::
    :maxdepth: 2
    :caption: Tutorial

    tutorial_web_ui_analyze_docker_image
    tutorial_web_ui_review_scan_results
    tutorial_cli_analyze_docker_image
    tutorial_cli_analyze_codebase
    tutorial_api_analyze_package_archive
    tutorial_license_policies
    tutorial_vulnerablecode_integration

.. toctree::
    :maxdepth: 2
    :caption: Reference Documentation

    scanpipe-concepts
    built-in-pipelines
    custom-pipelines
    scanpipe-pipes
    project-configuration
    data-models
    output-files
    command-line-interface
    rest-api
    automation
    application-settings
    distros-os-images

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
